============================================
Configuration
============================================

audioinfo is a flexible simulator, which has flexible configuration options. You can write your own configuration file to customize the simulation.

.. autopydantic_model:: audioinfo.config.schema.SourceDataloaderConf

.. autopydantic_model:: audioinfo.config.schema.Mixer

.. autopydantic_model:: audioinfo.config.schema.RIRSimulator
